@@ -1,3 +1,5 @@
+#!/user/bin/env python
+# -*- coding: utf-8 -*-
 '''
 Copyright (c) 2016 Behalf Inc.
 
@@ -8,7 +10,6 @@ The above copyright notice and this permission notice shall be included in all c
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 '''
 from loguru import logger
-from pprint import pformat
 
 
 def convert(json_file, remove_background=False, duration_format=False, deduplicate=False):
@@ -41,21 +42,15 @@ def convert(json_file, remove_background=False, duration_format=False, deduplica
                     # TODO 需要对该bug进行修复，将",转换为"，/n/t
                     if 'error_message' in item["result"]:
                         error_msg = item["result"].pop('error_message')
-                        logger.info(f'错误error_msg信息输出:{error_msg}')
-                        error_msg_len = 0
                         for i in range(0, len(error_msg)):
                             if i == len(error_msg) - 1:
                                 error_msg[i] = error_msg[i] + '\n'
                             else:
                                 error_msg[i] = error_msg[i] + '\n\t'
-                            error_msg_len += len(error_msg[i])
-                        logger.error(error_msg)
-                        logger.info(f'len(error_message):{error_msg_len}')
                         error_msg_info = str((str(error_msg).replace("\"", "").replace("\\'", "").replace("\'",
                                                                                                           "").replace(
-                            "\\n", "\n").replace("\\t", "\t"))[:5000])
+                            "\\n", "\n").replace("\\t,", "\t"))[:5000])
                         item["result"]["error_message"] = error_msg_info
-                        logger.info(f'错误信息输出:{item["result"]["error_message"]}')
                     if 'duration' in item["result"] and duration_format:
                         item["result"]["duration"] = int(item["result"]["duration"] * 1000000000)
                 else:
